![MIT License](https://img.shields.io/github/license/kown7/pymergevcd "MIT License")

# Introduction

Merge VCD files, optionally to create a diff on various files and signals.

Also a playground for [sltoo](https://www.github.com/kown7/sltoo).

Requirements and architecure documents are [here](https://kown7.github.com/pymergevcd).


# Installation

```bash
pip install pymergevcd
```

## Requirements

Python 3.6+.

## Documentation

Please see the `docs` folder.

## Usage

pymergevcd -o merged_out.vcd in1.vcd in2.vcd 

